# Einops

::: torchlinops.linops.Rearrange
    options:
        inherited_members: false
        members:
            - __init__
            - normal

::: torchlinops.linops.SumReduce
    options:
        inherited_members: false
        members:
            - __init__
            - normal

::: torchlinops.linops.Repeat
    options:
        inherited_members: false
        members:
            - __init__
